==> python_ms-1.0.0-py3-none-any.whl: CHANGELOG.md <==

# Python-ms Changelog

All notable changes to this project will be documented in this file.

The format is based on [CHANGELOG.md](http://changelog.md/)
and this project adheres to [Semantic Versioning](http://semver.org/).

<!-- 
TEMPLATE

## [major.minor.patch] - yyyy-mm-dd

A message that notes the main changes in the update.

### Added

### Changed

### Deprecated

### Fixed

### Removed

### Security

_______________________________________________________________________________
 
 -->

<!--
EXAMPLE

## [0.2.0] - 2021-06-02

Lorem Ipsum dolor sit amet.

### Added

- Cat pictures hidden in the library
- Added beeswax to the gears

### Changed

- Updated localisation files

-->

<!--
_______________________________________________________________________________

## [1.0.0] - 2022-12-20

This update fixes a handful of things, readying the package for official
release.

### Added

- Badges to `README.md`

### Changed

- Updated GitHub Actions workflows to use newer versions

### Fixed

- Swapped `Ellipsis` for `pass` in the hopes of getting coverage reports ignore
  them

-->

_______________________________________________________________________________

## [1.0.0] - 2022-12-20

This update fixes a handful of things, readying the package for official
release.

### Added

- Badges to `README.md`

### Changed

- Updated GitHub Actions workflows to use newer versions

### Fixed

- Swapped `Ellipsis` for `pass` in the hopes of getting coverage reports ignore
  them

_______________________________________________________________________________

## [0.9.0] - 2022-12-20

This update adds all planned fuctionality for the project.
Strings are parsed into integers, and vice versa.

### Added

- String to int conversion for microseconds
- Int to string conversion for microseconds
- Added more GitHub Actions workflows for PyPI uploads
- Full unit test coverage

### Changed

- Moved constants to their own file
- Updated linters and cleaned up the codebase
- Updated localisation files

### Fixed

- Fixed a bug with the regex query

_______________________________________________________________________________

## [0.1.0] - 2022-12-17

This is the initial version of the project.

### Added

- The base project

<!-- markdownlint-configure-file {
    "MD022": false,
    "MD024": false,
    "MD030": false,
    "MD032": false
} -->
<!--
    MD022: Blanks around headings
    MD024: No duplicate headings
    MD030: Spaces after list markers
    MD032: Blanks around lists
-->

==> python_ms-1.1.0-py3-none-any.whl: CHANGELOG.md <==

# Python-ms Changelog

All notable changes to this project will be documented in this file.

The format is based on [CHANGELOG.md](http://changelog.md/)
and this project adheres to [Semantic Versioning](http://semver.org/).

<!-- 
TEMPLATE

## [major.minor.patch] - yyyy-mm-dd

A message that notes the main changes in the update.

### Added

### Changed

### Deprecated

### Fixed

### Removed

### Security

_______________________________________________________________________________
 
 -->

<!--
EXAMPLE

## [0.2.0] - 2021-06-02

Lorem Ipsum dolor sit amet.

### Added

- Cat pictures hidden in the library
- Added beeswax to the gears

### Changed

- Updated localisation files

-->

<!--
_______________________________________________________________________________

## [1.1.0] - 2023-05-29

Fixed a potential catastrophic backtracking vulnerability with a regular
expression used to parse strings in the package.

### Changed

- Updated dependencies
- Replaced Pylint and Flake8 with Ruff

### Fixed

- Fixed miscellaneous linting issues

### Security

- A regular expression used to parse strings was found to have a potential
  catastrophic backtracking vulnerability; this was fixed by replacing the
  regex with a non-vulnerable variant

-->

_______________________________________________________________________________

## [1.1.0] - 2023-05-29

Fixed a potential catastrophic backtracking vulnerability with a regular
expression used to parse strings in the package.

### Changed

- Updated dependencies
- Replaced Pylint and Flake8 with Ruff

### Fixed

- Fixed miscellaneous linting issues

### Security

- A regular expression used to parse strings was found to have a potential
  catastrophic backtracking vulnerability; this was fixed by replacing the
  regex with a non-vulnerable variant

_______________________________________________________________________________

## [1.0.2] - 2023-02-09

Updated dependencies, metadata files, and GitHub Actions workflows.

### Added

- Added automated GitHub release builds
- Added Dependabot auto-updates
- Added `CODEOWNERS`

### Changed

- Updated wording from American English to British English, because we have
  our dignity
- Releases are now made from tags instead of merges

### Fixed

- Fixed a broken coverage option

_______________________________________________________________________________

## [1.0.1] - 2022-12-20

A bunch of small fixes.

### Added

- Added keywords to PyPI

### Changed

- Updated development status to stable

### Fixed

- Fixed `Makefile`

### Removed

- The source code link was unnecessary

_______________________________________________________________________________

## [1.0.0] - 2022-12-20

This update fixes a handful of things, readying the package for official
release.

### Added

- Badges to `README.md`

### Changed

- Updated GitHub Actions workflows to use newer versions

### Fixed

- Swapped `Ellipsis` for `pass` in the hopes of getting coverage reports ignore
  them

_______________________________________________________________________________

## [0.9.0] - 2022-12-20

This update adds all planned fuctionality for the project.
Strings are parsed into integers, and vice versa.

### Added

- String to int conversion for microseconds
- Int to string conversion for microseconds
- Added more GitHub Actions workflows for PyPI uploads
- Full unit test coverage

### Changed

- Moved constants to their own file
- Updated linters and cleaned up the codebase
- Updated localisation files

### Fixed

- Fixed a bug with the regex query

_______________________________________________________________________________

## [0.1.0] - 2022-12-17

This is the initial version of the project.

### Added

- The base project

<!-- markdownlint-configure-file {
    "MD022": false,
    "MD024": false,
    "MD030": false,
    "MD032": false
} -->
<!--
    MD022: Blanks around headings
    MD024: No duplicate headings
    MD030: Spaces after list markers
    MD032: Blanks around lists
-->
